@@ -1,17 +1,16 @@
-from pyrle.rle import Rle
-from pyrle.version import __version__
-from pyrle.rledict import RleDict
-from pyrle.methods import coverage
-
 import pandas as pd
-import numpy as np
+from importlib.metadata import version
 
-from collections import defaultdict, OrderedDict
+from pyrle.rle import Rle
+from pyrle.rledict import RleDict
+
+
+__version__ = version("pyrle")
 
 PyRles = RleDict
 
-def from_csv(f, sep="\t"):
 
+def from_csv(f, sep="\t"):
     """Read PyRle from CSV.
 
     >>>
