@@ -1,27 +1,24 @@
-import pandas as pd
-import numpy as np
-
-from pyrle import Rle
-from pyrle import rledict as rd
-from pyrle.src.coverage import _coverage
-
-from natsort import natsorted
-
-from sys import stderr
-
+import os
 from collections import defaultdict
 
-import os
+import numpy as np
+import pandas as pd
+from natsort import natsorted  # type: ignore
+
+from pyrle import Rle  # type: ignore
+from pyrle import rledict as rd  # type: ignore
+from pyrle.src.coverage import _coverage  # type: ignore
+
 
 class suppress_stdout_stderr(object):
-    '''
+    """
     A context manager for doing a "deep suppression" of stdout and stderr in
     Python, i.e. will suppress all print, even if the print originates in a
     compiled C/Fortran sub-function.
        This will not suppress raised exceptions, since exceptions are printed
     to stderr just before a script exits, and after the context manager has
     exited (at least, I think that is why it lets exceptions through).
-    '''
+    """
 
     def __init__(self):
         # Open a pair of null files
@@ -42,8 +39,8 @@ class suppress_stdout_stderr(object):
         os.close(self.null_fds[0])
         os.close(self.null_fds[1])
 
-def _merge_rles(rle):
 
+def _merge_rles(rle):
     new_dict = {}
     dd = defaultdict(list)
     for chromosome, strand in rle.rles.keys():
@@ -59,7 +56,6 @@ def _merge_rles(rle):
 
 
 def ensure_both_or_none_stranded(self, other):
-
     # means other not stranded
     if self.stranded:
         self.rles = _merge_rles(self)
@@ -70,32 +66,35 @@ def ensure_both_or_none_stranded(self, other):
 
 
 def chromosomes_in_both_self_other(self, other):
+    chromosomes_in_both = natsorted(set(self.rles.keys()).intersection(other.rles.keys()))
+    chromosomes_in_self_not_other = natsorted(set(self.rles.keys()) - set(other.rles.keys()))
+    chromosomes_in_other_not_self = natsorted(set(other.rles.keys()) - set(self.rles.keys()))
 
-    chromosomes_in_both = natsorted(
-        set(self.rles.keys()).intersection(other.rles.keys()))
-    chromosomes_in_self_not_other = natsorted(
-        set(self.rles.keys()) - set(other.rles.keys()))
-    chromosomes_in_other_not_self = natsorted(
-        set(other.rles.keys()) - set(self.rles.keys()))
-
-    return chromosomes_in_both, chromosomes_in_self_not_other, chromosomes_in_other_not_self
+    return (
+        chromosomes_in_both,
+        chromosomes_in_self_not_other,
+        chromosomes_in_other_not_self,
+    )
 
 
 def binary_operation(operation, self, other, nb_cpu=1):
-
     func = {"div": __div, "mul": __mul, "add": __add, "sub": __sub}[operation]
     func, get = rd.get_multithreaded_funcs(func, nb_cpu)
 
     if nb_cpu > 1:
-        import ray
+        import ray  # type: ignore
+
         with suppress_stdout_stderr():
             ray.init(num_cpus=nb_cpu)
 
     if self.stranded != other.stranded:
         self, other = ensure_both_or_none_stranded(self, other)
 
-    chromosomes_in_both, chromosomes_in_self_not_other, chromosomes_in_other_not_self = chromosomes_in_both_self_other(
-        self, other)
+    (
+        chromosomes_in_both,
+        chromosomes_in_self_not_other,
+        chromosomes_in_other_not_self,
+    ) = chromosomes_in_both_self_other(self, other)
 
     both_results = []
     for c in chromosomes_in_both:
@@ -114,35 +113,30 @@ def binary_operation(operation, self, other, nb_cpu=1):
     rles = {
         k: v
         for k, v in zip(
-            chromosomes_in_both + chromosomes_in_self_not_other +
-            chromosomes_in_other_not_self,
-            get(both_results + self_results + other_results))
+            chromosomes_in_both + chromosomes_in_self_not_other + chromosomes_in_other_not_self,
+            get(both_results + self_results + other_results),
+        )
     }
     return rd.RleDict(rles)
 
 
 def __add(self, other):
-
     return self + other
 
 
 def __sub(self, other):
-
     return self - other
 
 
 def __div(self, other):
-
     return self / other
 
 
 def __mul(self, other):
-
     return self * other
 
 
 def coverage(df, **kwargs):
-
     value_col = kwargs.get("value_col", None)
 
     if value_col:
@@ -150,19 +144,12 @@ def coverage(df, **kwargs):
     else:
         values = np.ones(len(df))
 
-    starts_df = pd.DataFrame({
-        "Position": df.Start,
-        "Value": values
-    })["Position Value".split()]
-    ends_df = pd.DataFrame({
-        "Position": df.End,
-        "Value": -1 * values
-    })["Position Value".split()]
+    starts_df = pd.DataFrame({"Position": df.Start, "Value": values})["Position Value".split()]
+    ends_df = pd.DataFrame({"Position": df.End, "Value": -1 * values})["Position Value".split()]
     _df = pd.concat([starts_df, ends_df], ignore_index=True)
     _df = _df.sort_values("Position", kind="mergesort")
 
-    if _df.Position.dtype.name == "int32":
-        _df.Position = _df.Position.astype(np.int64)
+    _df.Position = _df.Position.astype(np.int64)
 
     runs, values = _coverage(_df.Position.values, _df.Value.values)
 
@@ -170,11 +157,9 @@ def coverage(df, **kwargs):
 
 
 def to_ranges_df_strand(rle, k):
-
     chromosome, strand = k
     starts, ends, values = _to_ranges(rle)
-    df = pd.concat([pd.Series(r) for r in [starts, ends, values]],
-                    axis=1)
+    df = pd.concat([pd.Series(r) for r in [starts, ends, values]], axis=1)
     df.columns = "Start End Score".split()
     df.insert(0, "Chromosome", chromosome)
     df.insert(df.shape[1], "Strand", strand)
@@ -184,10 +169,8 @@ def to_ranges_df_strand(rle, k):
 
 
 def to_ranges_df_no_strand(rle, k):
-
     starts, ends, values = _to_ranges(rle)
-    df = pd.concat([pd.Series(r) for r in [starts, ends, values]],
-                    axis=1)
+    df = pd.concat([pd.Series(r) for r in [starts, ends, values]], axis=1)
     df.columns = "Start End Score".split()
     df.insert(0, "Chromosome", k)
     df = df[df.Score != 0]
@@ -196,36 +179,19 @@ def to_ranges_df_no_strand(rle, k):
 
 
 def to_ranges(grles, nb_cpu=1):
-
-    from pyranges import PyRanges
+    import pyranges as pr# type: ignore
 
     func = to_ranges_df_strand if grles.stranded else to_ranges_df_no_strand
 
-    if nb_cpu > 1:
-        import ray
-        ray.init(num_cpus=nb_cpu)
-        func = ray.remote(func)
-        get = ray.get
-    else:
-        func.remote = func
-        get = lambda x: x
+    dfs = {k: func(v, k) for k, v in grles.items()}
 
-    dfs, keys = [], []
-    for k, v in grles.items():
-        result = func.remote(v, k)
-        dfs.append(result)
-        keys.append(k)
-
-    dfs = {k: v for (k, v) in zip(keys, get(dfs))}
-
-    if nb_cpu > 1:
-        ray.shutdown()
-
-    return PyRanges(dfs)
+    try:  # new pyranges
+        return pr.from_dfs(dfs)
+    except:  # legacy pyranges
+        return pr.PyRanges(pd.concat(dfs.values()))
 
 
 def _to_ranges(rle):
-
     runs = pd.Series(rle.runs)
     starts = pd.Series([0] + list(runs)).cumsum()
 
@@ -240,5 +206,8 @@ def _to_ranges(rle):
     ends = ends.loc[end_idx]
     values = values[start_idx].reset_index(drop=True)
 
-    return starts.astype(int).reset_index(
-        drop=True), ends.astype(int).reset_index(drop=True), values
+    return (
+        starts.astype(int).reset_index(drop=True),
+        ends.astype(int).reset_index(drop=True),
+        values,
+    )
